﻿using RenovationWorkContracts.BindingModels;
using RenovationWorkContracts.SearchModels;
using RenovationWorkContracts.StoragesContracts;
using RenovationWorkContracts.ViewModels;
using RenovationWorkListImplement.Models;

namespace RenovationWorkListImplement.Implements
{
    public class OrderStorage : IOrderStorage
    {
        private readonly DataListSingleton _source;
        public OrderStorage()
        {
            _source = DataListSingleton.GetInstance();
        }
        public List<OrderViewModel> GetFullList()
        {
            var result = new List<OrderViewModel>();
            foreach (var order in _source.Orders)
            {
                OrderViewModel thisorder = order.GetViewModel;
                Repair? repair = _source.Repairs.Find(x => x.Id == order.RepairId);
                string repairName = repair?.RepairName ?? string.Empty;
                thisorder.RepairName = repairName;
                result.Add(thisorder);
            }
            return result;
        }
        public List<OrderViewModel> GetFilteredList(OrderSearchModel model)
        {
            var result = new List<OrderViewModel>();
            if (model.Id.HasValue)
            {
                return result;
            }
            foreach (var order in _source.Orders)
            {
                if (model.Id.HasValue && order.Id == model.Id)
                {
                    OrderViewModel thisorder = order.GetViewModel;
                    Repair? repair = _source.Repairs.Find(x => x.Id == order.RepairId);
                    string repairName = repair?.RepairName ?? string.Empty;
                    thisorder.RepairName = repairName;
                    result.Add(thisorder);
                }
            }
            return result;
        }
        public OrderViewModel? GetElement(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return null;
            }
            foreach (var order in _source.Orders)
            {
                if ((model.Id.HasValue && order.Id == model.Id))
                {
                    OrderViewModel thisorder = order.GetViewModel;
                    Repair? repair = _source.Repairs.Find(x => x.Id == order.RepairId);
                    string repairName = repair?.RepairName ?? string.Empty;
                    thisorder.RepairName = repairName;
                    return thisorder;
                }
            }
            return null;
        }
        public OrderViewModel? Insert(OrderBindingModel model)
        {
            model.Id = 1;
            foreach (var order in _source.Orders)
            {
                if (model.Id <= order.Id)
                {
                    model.Id = order.Id + 1;
                }
            }
            var newOrder = Order.Create(model);
            if (newOrder == null)
            {
                return null;
            }
            _source.Orders.Add(newOrder);
            return newOrder.GetViewModel;
        }
        public OrderViewModel? Update(OrderBindingModel model)
        {
            foreach (var order in _source.Orders)
            {
                if (order.Id == model.Id)
                {
                    order.Update(model);
                    return order.GetViewModel;
                }
            }
            return null;
        }
        public OrderViewModel? Delete(OrderBindingModel model)
        {
            for (int i = 0; i < _source.Orders.Count; ++i)
            {
                if (_source.Orders[i].Id == model.Id)
                {
                    var element = _source.Orders[i];
                    _source.Repairs.RemoveAt(i);
                    return element.GetViewModel;
                }
            }
            return null;
        }
    }
}
